@@ -10,8 +10,13 @@ bme680 = adafruit_bme680.Adafruit_BME680_I2C(i2c, debug=False)
 # change this to match the location's pressure (hPa) at sea level
 bme680.sea_level_pressure = 1013.25
 
+# You will usually have to add an offset to account for the temperature of
+# the sensor. This is usually around 5 degrees but varies by use. Use a
+# separate temperature sensor to calibrate this one.
+temperature_offset = -5
+
 while True:
-    print("\nTemperature: %0.1f C" % bme680.temperature)
+    print("\nTemperature: %0.1f C" % bme680.temperature + temperature_offset)
     print("Gas: %d ohm" % bme680.gas)
     print("Humidity: %0.1f %%" % bme680.humidity)
     print("Pressure: %0.3f hPa" % bme680.pressure)
